==> ansible-10.0.0a2-py3-none-any.whl: ansible_collections/cisco/dnac/plugins/modules/interface_info.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: interface_info
short_description: Information module for Interface
description:
- Get all Interface.
- Get list of all properties & operations valid for an interface.
version_added: '6.0.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  interfaceUuid:
    description:
    - InterfaceUuid path parameter. Interface ID.
    type: str
requirements:
- dnacentersdk >= 2.6.0
- python >= 3.9
seealso:
- name: Cisco DNA Center documentation for Devices LegitOperationsForInterface
  description: Complete reference of the LegitOperationsForInterface API.
  link: https://developer.cisco.com/docs/dna-center/#!legit-operations-for-interface
notes:
  - SDK Method used are
    devices.Devices.legit_operations_for_interface,

  - Paths used are
    get /dna/intent/api/v1/interface/{interfaceUuid}/legit-operation,

"""

EXAMPLES = r"""
- name: Get all Interface
  cisco.dnac.interface_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    interfaceUuid: string
  register: result

"""

RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "type": "string",
        "properties": {
          "interfaceUuid": {
            "type": "string"
          },
          "properties": {
            "type": "string",
            "items": [
              {
                "type": "string",
                "properties": {
                  "name": {
                    "type": "string"
                  },
                  "applicable": {
                    "type": "string"
                  },
                  "failureReason": {
                    "type": "string"
                  }
                },
                "required": [
                  "string"
                ]
              }
            ]
          },
          "operations": {
            "type": "string",
            "items": [
              {
                "type": "string",
                "properties": {
                  "name": {
                    "type": "string"
                  },
                  "applicable": {
                    "type": "string"
                  },
                  "failureReason": {
                    "type": "string"
                  }
                },
                "required": [
                  "string"
                ]
              }
            ]
          }
        },
        "required": [
          "string"
        ]
      },
      "version": {
        "type": "string"
      }
    }
"""

==> ansible-10.1.0-py3-none-any.whl: ansible_collections/cisco/dnac/plugins/modules/interface_info.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: interface_info
short_description: Information module for Interface
description:
- Get all Interface.
- Get list of all properties & operations valid for an interface.
version_added: '6.0.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  interfaceUuid:
    description:
    - InterfaceUuid path parameter. Interface ID.
    type: str
requirements:
- dnacentersdk >= 2.7.1
- python >= 3.5
seealso:
- name: Cisco DNA Center documentation for Devices LegitOperationsForInterface
  description: Complete reference of the LegitOperationsForInterface API.
  link: https://developer.cisco.com/docs/dna-center/#!legit-operations-for-interface
notes:
  - SDK Method used are
    devices.Devices.legit_operations_for_interface,

  - Paths used are
    get /dna/intent/api/v1/interface/{interfaceUuid}/legit-operation,

"""

EXAMPLES = r"""
- name: Get all Interface
  cisco.dnac.interface_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    interfaceUuid: string
  register: result

"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "interfaceUuid": "string",
        "properties": [
          {
            "name": "string",
            "applicable": "string",
            "failureReason": "string"
          }
        ],
        "operations": [
          {
            "name": "string",
            "applicable": "string",
            "failureReason": "string"
          }
        ]
      },
      "version": "string"
    }
"""
